@@ -40,6 +40,7 @@
 #![deny(missing_docs)]
 #![warn(noop_method_call)]
 #![deny(unreachable_pub)]
+#![deny(clippy::all)]
 #![deny(clippy::await_holding_lock)]
 #![deny(clippy::cargo_common_metadata)]
 #![deny(clippy::cast_lossless)]
@@ -61,35 +62,12 @@
 #![warn(clippy::option_option)]
 #![warn(clippy::rc_buffer)]
 #![deny(clippy::ref_option_ref)]
+#![warn(clippy::semicolon_if_nothing_returned)]
 #![warn(clippy::trait_duplication_in_bounds)]
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
 #![deny(clippy::unwrap_used)]
 
-/// An error produced from type derived from type.  These errors can
-/// only occur when trying to convert to a type made with caret_enum!
-#[derive(Debug, Clone, PartialEq, Eq)]
-#[non_exhaustive]
-pub enum Error {
-    /// Tried to convert to an enumeration type from an integer that
-    /// didn't represent a member of that enumeration.
-    InvalidInteger,
-    /// Tried to convert to an enumeration type from a string that
-    /// didn't represent a member of that enumeration.
-    InvalidString,
-}
-
-impl std::fmt::Display for Error {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        match self {
-            Error::InvalidInteger => write!(f, "Integer was not member of this enumeration"),
-            Error::InvalidString => write!(f, "String was not member of this enumeration"),
-        }
-    }
-}
-
-impl std::error::Error for Error {}
-
 /// Declare an integer type with some named elements.
 ///
 /// This macro declares a struct that wraps an integer
